@@ -5,9 +5,8 @@ import pickle
 import tempfile
 import threading
 import time
-import zipfile
 from collections import OrderedDict, deque
-from typing import Any, Deque, Dict, Iterable, Iterator, List, Optional, Tuple, Union, cast
+from typing import Any, Deque, Dict, Iterator, List, Optional, Tuple, Union, cast
 
 from redun.executors import aws_utils
 from redun.executors.base import Executor, register_executor
@@ -57,21 +56,6 @@ def get_redun_lib_scratch_file(s3_scratch_prefix: str, lib_hash: str) -> str:
     return os.path.join(s3_scratch_prefix, "glue", f"redun-{lib_hash}.zip")
 
 
-def create_zip(zip_path: str, base_path: str, file_paths: Iterable[str]) -> File:
-    """
-    Create a tar file from local file paths.
-    """
-    zip_file = File(zip_path)
-
-    with zip_file.open("wb") as out:
-        with zipfile.ZipFile(out, mode="w") as stream:
-            for file_path in file_paths:
-                arcname = os.path.relpath(file_path, base_path)
-                stream.write(file_path, arcname)
-
-    return zip_file
-
-
 def get_redun_lib_files() -> Iterator[str]:
     """
     Iterates through the files of the redun library.
@@ -94,7 +78,7 @@ def package_redun_lib(s3_scratch_prefix: str) -> File:
         base_path = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
         temp_path = os.path.join(tmpdir, "redun.zip")
         lib_files = get_redun_lib_files()
-        temp_file = create_zip(temp_path, base_path, lib_files)
+        temp_file = aws_utils.create_zip(temp_path, base_path, lib_files)
 
         with temp_file.open("rb") as infile:
             lib_hash = hash_stream(infile)
@@ -413,7 +397,7 @@ class AWSGlueExecutor(Executor):
         if error:
             self.scheduler.reject_job(redun_job, error, error_traceback=error_traceback)
 
-    def _get_task_options(self, job: Job) -> dict:
+    def _get_job_options(self, job: Job) -> dict:
         """
         Determines task options for a job.
         """
@@ -446,10 +430,12 @@ class AWSGlueExecutor(Executor):
         if self.code_package is not False and self.code_file is None:
             code_package = self.code_package or {}
             assert isinstance(code_package, dict)
-            self.code_file = aws_utils.package_code(self.s3_scratch_prefix, code_package)
+            self.code_file = aws_utils.package_code(
+                self.s3_scratch_prefix, code_package, use_zip=True
+            )
 
         # Determine job options
-        task_options = self._get_task_options(job)
+        task_options = self._get_job_options(job)
 
         # Determine if we can reunite with a previous Glue output or job.
         glue_job_id: Optional[str] = None
@@ -497,6 +483,7 @@ class AWSGlueExecutor(Executor):
         assert job.task
         assert self.glue_job_name
         assert self.redun_zip_location
+        assert self.code_file
         client = aws_utils.get_aws_client("glue", aws_region=self.aws_region)
 
         try:
@@ -506,7 +493,7 @@ class AWSGlueExecutor(Executor):
                 glue_job_name=self.glue_job_name,
                 redun_zip_location=self.redun_zip_location,
                 s3_scratch_prefix=self.s3_scratch_prefix,
-                job_options=self._get_task_options(job),
+                job_options=self._get_job_options(job),
                 code_file=self.code_file,
                 aws_region=self.aws_region,
             )
@@ -540,15 +527,13 @@ def submit_glue_job(
     s3_scratch_prefix: str,
     glue_job_name: str,
     redun_zip_location: str,
+    code_file: File,
     job_options: dict = {},
-    code_file: Optional[File] = None,
     aws_region: str = aws_utils.DEFAULT_AWS_REGION,
 ) -> Dict[str, Any]:
     """
     Submits a redun task to AWS glue.
     """
-    module = a_task.func.__module__
-
     input_path = aws_utils.get_job_scratch_file(s3_scratch_prefix, job, aws_utils.S3_SCRATCH_INPUT)
     output_path = aws_utils.get_job_scratch_file(
         s3_scratch_prefix, job, aws_utils.S3_SCRATCH_OUTPUT
@@ -557,31 +542,38 @@ def submit_glue_job(
 
     # Assemble job arguments
     assert job.eval_hash
-    job_args = {
-        "--extra-py-files": redun_zip_location,
+    glue_args = {
         "--check-version": aws_utils.REDUN_REQUIRED_VERSION,
         "--input": input_path,
         "--output": output_path,
-        "--script": module,
+        "--script": a_task.load_module,
         "--task": a_task.fullname,
         "--error": error_path,
-        "--code": code_file.path if code_file else "",
         "--job-hash": job.eval_hash,
     }
+
+    # Comma separated string of Python modules to be installed with pip before job start.
     if job_options.get("additional_libs"):
-        job_args["--additional-python-modules"] = (
+        glue_args["--additional-python-modules"] = (
             DEFAULT_ADDITIONAL_PYTHON_MODULES + "," + ",".join(job_options["additional_libs"])
         )
 
-    # Copy extra Python files to S3, as Glue requires them to be there.
-    scratch_dir = aws_utils.get_job_scratch_dir(s3_scratch_prefix, job)
-    if job_options.get("extra_py_files"):
-        job_args["--extra-py-files"] += ",".join(
-            aws_utils.copy_to_s3(f, scratch_dir) for f in job_options["extra_py_files"]
-        )
+    # Extra python and data files are specified as comma separated strings.
+    # Files are first copied to S3, as Glue requires them to be there.
 
+    # Extra py files will be in an importable location at job start.
+    # They can be either importable zip files, or .py source files.
+    # Redun and the code to run are provided as importable zip files.
+    scratch_dir = aws_utils.get_job_scratch_dir(s3_scratch_prefix, job)
+
+    glue_args["--extra-py-files"] = ",".join([redun_zip_location, code_file.path]) + ","
+    if job_options.get("extra_py_files"):
+        addl_files = [aws_utils.copy_to_s3(f, scratch_dir) for f in job_options["extra_py_files"]]
+        glue_args["--extra-py-files"] += ",".join(addl_files)
+
+    # Extra files will be available in job's $PWD.
     if job_options.get("extra_files"):
-        job_args["--extra-files"] = ",".join(
+        glue_args["--extra-files"] = ",".join(
             aws_utils.copy_to_s3(f, scratch_dir) for f in job_options["extra_files"]
         )
 
@@ -594,7 +586,7 @@ def submit_glue_job(
     glue_client = aws_utils.get_aws_client("glue", aws_region=aws_region)
     result = glue_client.start_job_run(
         JobName=glue_job_name,
-        Arguments=job_args,
+        Arguments=glue_args,
         Timeout=job_options["timeout"],
         WorkerType=job_options["worker_type"],
         NumberOfWorkers=job_options["workers"],
