@@ -263,6 +263,7 @@ class Job:
         self.parent_job: Optional[Job] = parent_job
         self.handle_forks: Dict[str, int] = defaultdict(int)
         self.job_tags: List[Tuple[str, Any]] = []
+        self.execution_tags: List[Tuple[str, Any]] = []
         self.value_tags: List[Tuple[str, List[Tuple[str, Any]]]] = []
         self._status: Optional[str] = None
 
@@ -382,6 +383,7 @@ class Job:
         self.result_promise = None
         self.result = None
         self.job_tags.clear()
+        self.execution_tags.clear()
         self.value_tags.clear()
 
         for child_job in self.child_jobs:
@@ -1317,6 +1319,7 @@ class Scheduler:
         Record tags acquired during Job.
         """
         assert job.task
+        assert job.execution
 
         # Record value tags.
         for value_hash, tags in job.value_tags:
@@ -1331,6 +1334,14 @@ class Scheduler:
                 entity_type=TagEntityType.Job, entity_id=job.id, tags=job_tags
             )
 
+        # Record Execution tags.
+        if job.execution_tags:
+            self.backend.record_tags(
+                entity_type=TagEntityType.Execution,
+                entity_id=job.execution.id,
+                tags=job.execution_tags,
+            )
+
         # Record Task tags.
         task_tags = job.task.get_task_option("tags")
         if task_tags:
@@ -1367,6 +1378,13 @@ class Scheduler:
         This function runs on the main scheduler thread. Use
         :method:`Scheduler.reject_job()` if calling from another thread.
         """
+
+        # Attach the traceback to the error so the redun traceback is always available on the error
+        # itself. In some cases (like AWS batch), the error will be constructed by unpickling a
+        # pickled Excetption(__traceback__ is not included when pickling). By attaching the
+        # traceback here, we make sure the traceback is available for downstream handlers.
+        error.redun_traceback = error_traceback
+
         if job:
             assert job.task
             assert job.args_hash
@@ -1916,21 +1934,48 @@ def apply_tags(
     parent_job: Job,
     sexpr: SchedulerExpression,
     value: Any,
-    tags: List[Tuple[str, Any]],
+    tags: List[Tuple[str, Any]] = [],
+    job_tags: List[Tuple[str, Any]] = [],
+    execution_tags: List[Tuple[str, Any]] = [],
 ) -> Promise:
     """
-    Apply tags to a value.
+    Apply tags to a value, job, or execution.
 
     Returns the original value.
+
+    .. code-block:: python
+
+        @task
+        def task1():
+            x = 10
+            # Apply tags on the value 10.
+            return apply_tags(x, [("env": "prod", "project": "acme")])
+
+        @task
+        def task2():
+            x = 10
+            # Apply tags on the current job.
+            return apply_tags(x, job_tags=[("env": "prod", "project": "acme")])
+
+        @task
+        def task3():
+            x = 10
+            # Apply tags on the current execution.
+            return apply_tags(x, execution_tags=[("env": "prod", "project": "acme")])
     """
 
     def then(args):
-        value, tags = args
-        value_hash = scheduler.backend.record_value(value)
-        parent_job.value_tags.append((value_hash, tags))
+        value, tags, job_tags, execution_tags = args
+        if tags:
+            value_hash = scheduler.backend.record_value(value)
+            parent_job.value_tags.append((value_hash, tags))
+        parent_job.job_tags.extend(job_tags)
+        parent_job.execution_tags.extend(execution_tags)
         return value
 
-    return scheduler.evaluate((value, tags), parent_job=parent_job).then(then)
+    return scheduler.evaluate((value, tags, job_tags, execution_tags), parent_job=parent_job).then(
+        then
+    )
 
 
 @task(
