@@ -150,7 +150,7 @@ def test_scheduler_incremental(scheduler: Scheduler) -> None:
 
     # Simulate a code change to run_gatk task.
 
-    @task()  # type: ignore # noqa: F811
+    @task()  # type: ignore[no-redef]
     def run_gatk(align):
         task_calls.append("run_gatk")
         calls = "calls2({})".format(align)
@@ -164,7 +164,7 @@ def test_scheduler_incremental(scheduler: Scheduler) -> None:
 
     # A reverted code change should be fully memoized too.
 
-    @task()  # type: ignore # noqa: F811
+    @task()  # type: ignore[no-redef]
     def run_gatk(align):
         task_calls.append("run_gatk")
         calls = "calls({})".format(align)
@@ -436,7 +436,7 @@ def test_higher_order(scheduler: Scheduler) -> None:
     assert task_calls == []
 
     # Changing a child of adder(), changes adder(). Caching should detect this.
-    @task()  # type: ignore # noqa: F811
+    @task()  # type: ignore[no-redef]
     def get_offset():
         task_calls.append("get_offset")
         return 20
@@ -521,7 +521,7 @@ def test_higher_order2(scheduler: Scheduler) -> None:
     assert task_calls == []
 
     # Change definition of task that was cached.
-    @task()  # type: ignore # noqa: F811
+    @task()  # type: ignore[no-redef]
     def adder(a, b):
         task_calls.append("adder")
         return a + b
@@ -533,7 +533,7 @@ def test_higher_order2(scheduler: Scheduler) -> None:
     assert task_calls == ["chooser", "adder"]
 
     # Changing a child of multiplier, changes multiplier. Caching should detect this.
-    @task()  # type: ignore # noqa: F811
+    @task()  # type: ignore[no-redef]
     def get_offset():
         task_calls.append("get_offset")
         return 20
@@ -682,8 +682,10 @@ def test_log_job_status(scheduler: Scheduler) -> None:
         logs.extend(messages)
 
     with patch.object(scheduler, "log", wraps=log):
+        report = scheduler.get_job_status_report()
         scheduler.log_job_statuses()
 
+    assert report == logs
     assert logs[1:] == [
         "| TASK    PENDING RUNNING  FAILED  CACHED    DONE   TOTAL",
         "| ",
@@ -1227,7 +1229,7 @@ def test_catch_task_react(scheduler: Scheduler) -> None:
     assert calls == ["safe"]
 
     # Updating safe task should force re-execution.
-    @task()  # type: ignore # noqa: F811
+    @task()  # type: ignore[no-redef]
     def safe():
         calls.append("safe2")
         return 2 / 1
@@ -1243,7 +1245,7 @@ def test_catch_task_react(scheduler: Scheduler) -> None:
     assert calls == ["faulty", "recover"]
 
     # Updating recover task should force re-execution.
-    @task()  # type: ignore # noqa: F811
+    @task()  # type: ignore[no-redef]
     def recover(error):
         calls.append("recover2")
         return 2.0
@@ -1285,7 +1287,7 @@ def test_catch_deep_task_react(scheduler: Scheduler) -> None:
     assert calls == ["safe", "deep"]
 
     # Updating deep task should force re-execution.
-    @task()  # type: ignore # noqa: F811
+    @task()  # type: ignore[no-redef]
     def deep(denom):
         calls.append("deep2")
         return 2 / denom
@@ -1327,7 +1329,7 @@ def test_catch_deep_recover_react(scheduler: Scheduler) -> None:
     assert calls == ["faulty", "recover", "deep"]
 
     # Updating deep task should force re-execution.
-    @task()  # type: ignore # noqa: F811
+    @task()  # type: ignore[no-redef]
     def deep():
         calls.append("deep2")
         return 2
